# Path and Probe

Path commands are used to define a line through your model by specifying a series of points. You can view results along the path in the form of an X-Y plot. Probe commands are used to determine model data and analysis results at selected locations.

## Create paths in Session

```{eval-rst}
.. autoclass:: abaqus.PathAndProbe.PathSession.PathSession
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

## Create free bodies in Session

```{eval-rst}
.. autoclass:: abaqus.PathAndProbe.FreeBody.FreeBody
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

## Classes

### CurrentProbeValues

```{eval-rst}
.. autoclass:: abaqus.PathAndProbe.CurrentProbeValues.CurrentProbeValues
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### NodeQuery

```{eval-rst}
.. autoclass:: abaqus.PathAndProbe.NodeQuery.NodeQuery
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Path

```{eval-rst}
.. autoclass:: abaqus.PathAndProbe.Path.Path
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ProbeOptions

```{eval-rst}
.. autoclass:: abaqus.PathAndProbe.ProbeOptions.ProbeOptions
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ProbeReport

```{eval-rst}
.. autoclass:: abaqus.PathAndProbe.ProbeReport.ProbeReport
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SelectedProbeValues

```{eval-rst}
.. autoclass:: abaqus.PathAndProbe.SelectedProbeValues.SelectedProbeValues
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Spectrum

```{eval-rst}
.. autoclass:: abaqus.PathAndProbe.Spectrum.Spectrum
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Stream

```{eval-rst}
.. autoclass:: abaqus.PathAndProbe.Stream.Stream
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

% This is a comment ro supress the warning "(ERROR/3) Document may not end with a transition."
